@@ -25,7 +25,7 @@ class HighlightItem : public PixmapItem
 {
 public:
     /* creates a highlight at field coordinates (x,y) */
-    HighlightItem(Renderer::Resource resource, int x, int y, QGraphicsItem *parent = 0);
+    HighlightItem(Renderer::Resource resource, int x, int y, QGraphicsItem *parent = nullptr);
 
     /* switches current highlight on/off according to the currently
       focused point p */
